/*
 * JINGLE
 *
 * Copyright (C) 2004-2008  Peter C. Tribble
 *
 * You may contact the author by email: peter.tribble@gmail.com
 *
 * JingleCheckList - a list of JCheckBoxes
 */

package uk.co.petertribble.jingle;

import javax.swing.JPanel;
import javax.swing.JCheckBox;
import java.util.Hashtable;
import java.util.Enumeration;
import java.util.Vector;

/**
 * A list of JCheckBoxes.
 *
 * @author Peter C. Tribble (peter.tribble@gmail.com)
 */
public class JingleCheckList extends JPanel {

    private Vector keys;
    private Vector values;
    private Vector checkboxes;

    /**
     * Create a JPanel with a list of checkboxes.
     *
     * @param keys A Vector of keys identifying the checkbox.
     * @param values A Vector of values that are Strings used as
     *  the Checkbox text.
     */
    public JingleCheckList(Vector keys, Vector values) {
	this.keys = keys;
	this.values = values;
	buildpanel();
    }

    /**
     * Create a JPanel with a list of checkboxes.
     *
     * @param items A Hashtable of items. The key identifies the
     *   checkbox, the value is a String used as the Checkbox text.
     */
    public JingleCheckList(Hashtable items) {
	Enumeration e1 = items.keys();
	keys = new Vector();
	values = new Vector();
	while (e1.hasMoreElements()) {
	    String s = (String) e1.nextElement();
	    keys.add(s);
	    values.add((String) items.get(s));
	}
	buildpanel();
    }

    private void buildpanel() {
	checkboxes = new Vector();
	for (int i = 0; i < values.size(); i++) {
	    JCheckBox cb = new JCheckBox((String) values.elementAt(i));
	    checkboxes.add(cb);
	    add(cb);
	}
    }

    /**
     * Return a Hashtable of keys and true/false depending on
     * whether the checkbox is selected.
     */
    public Hashtable status() {
	Hashtable h = new Hashtable();
	for (int i = 0; i < checkboxes.size(); i++) {
	    h.put((String) keys.elementAt(i), new Boolean(
			((JCheckBox) checkboxes.elementAt(i)).isSelected()));
	}
	return h;
    }

    /**
     * Return a Vector of keys that are selected
     */
    public Vector truekeys() {
	Vector v = new Vector();
	for (int i = 0; i < checkboxes.size(); i++) {
	    if (((JCheckBox) checkboxes.elementAt(i)).isSelected()) {
		v.add((String) keys.elementAt(i));
	    }
	}
	return v;
    }

}
